.. Modoboa documentation master file, created by
   sphinx-quickstart on Mon Jan  3 22:29:25 2011.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Modoboa documentation
=====================

.. image:: _static/modoboa_logo.png
   :align: center

Overview
--------

Modoboa is a mail hosting and management platform including a modern
and simplified Web User Interface designed to work with `Postfix
<http://www.postfix.org>`_ and `Dovecot <http://www.dovecot.org>`_.

And it is extensible by nature and comes with a lot of additional extensions:

+---------------------------------------------------------+-------------------------+------------------------------------------------------+
|Name                                                     |Description              |Documentation                                         |
|                                                         |                         |                                                      |
|                                                         |                         |                                                      |
|                                                         |                         |                                                      |
+=========================================================+=========================+======================================================+
|`modoboa-amavis                                          |A frontend for `Amavis   |https://modoboa-amavis.readthedocs.io                 |
|<https://github.com/modoboa/modoboa-amavis>`_            |<http://www.amavis.org>`_|                                                      |
|                                                         |                         |                                                      |
|                                                         |                         |                                                      |
+---------------------------------------------------------+-------------------------+------------------------------------------------------+
|`modoboa-pfxadmin-migrate                                |A tool to migrate from   |https://github.com/modoboa/modoboa-pfxadmin-migrate   |
|<https://github.com/modoboa/modoboa-pfxadmin-migrate>`_  |Postfixadmin             |                                                      |
+---------------------------------------------------------+-------------------------+------------------------------------------------------+

Table of contents
-----------------

.. toctree::
   :maxdepth: 1

   installation
   upgrade
   configuration
   moving
   rest_api
   contributing
   contributors
